@@ -2,6 +2,7 @@ import re
 from collections import defaultdict
 
 from selenium import webdriver
+from selenium.webdriver.common.by import By
 
 from ..utils import frame_from_ranges, ensure_and_log
 
@@ -12,12 +13,12 @@ base_url = 'https://mendel.imp.ac.at/METHODS/seg.server.html'
 def submit_and_get_result(seq):
     with webdriver.Firefox() as driver:
         driver.get(base_url)
-        input_el = driver.find_element_by_name('Sequence')
+        input_el = driver.find_element(By.NAME, 'Sequence')
         input_el.click()  # needed otherwise clicks are not registered
         input_el.send_keys(seq)
-        driver.find_element_by_xpath('/html/body/a/form/pre/p[1]/input[1]').click()
+        driver.find_element(By.XPATH, '/html/body/a/form/pre/p[1]/input[1]').click()
         # get result text
-        result = driver.find_element_by_xpath('/html/body/pre').text
+        result = driver.find_element(By.XPATH, '/html/body/pre').text
     return result
 
 
